==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/subsystem/impl/O_TFRSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.subsystem.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.body.OperationBodySet;
import io.ciera.tool.sql.ooaofooa.body.impl.OperationBodySetImpl;
import io.ciera.tool.sql.ooaofooa.domain.DataTypeSet;
import io.ciera.tool.sql.ooaofooa.domain.DimensionsSet;
import io.ciera.tool.sql.ooaofooa.domain.impl.DataTypeSetImpl;
import io.ciera.tool.sql.ooaofooa.domain.impl.DimensionsSetImpl;
import io.ciera.tool.sql.ooaofooa.invocation.OperationInvocationSet;
import io.ciera.tool.sql.ooaofooa.invocation.impl.OperationInvocationSetImpl;
import io.ciera.tool.sql.ooaofooa.message.OperationMessageSet;
import io.ciera.tool.sql.ooaofooa.message.impl.OperationMessageSetImpl;
import io.ciera.tool.sql.ooaofooa.subsystem.DeferralSet;
import io.ciera.tool.sql.ooaofooa.subsystem.ModelClassSet;
import io.ciera.tool.sql.ooaofooa.subsystem.O_TFR;
import io.ciera.tool.sql.ooaofooa.subsystem.O_TFRSet;
import io.ciera.tool.sql.ooaofooa.subsystem.OperationParameterSet;
import io.ciera.tool.sql.ooaofooa.subsystem.impl.DeferralSetImpl;
import io.ciera.tool.sql.ooaofooa.subsystem.impl.ModelClassSetImpl;
import io.ciera.tool.sql.ooaofooa.subsystem.impl.O_TFRSetImpl;
import io.ciera.tool.sql.ooaofooa.subsystem.impl.OperationParameterSetImpl;
import io.ciera.tool.sql.ooaofooa.value.OperationValueSet;
import io.ciera.tool.sql.ooaofooa.value.impl.OperationValueSetImpl;

import java.util.Arrays;
import java.util.List;

import ooaofooa.datatypes.ActionDialect;
import ooaofooa.datatypes.ParseStatus;
import ooaofooa.datatypes.Scope;


public class O_TFRSetImpl extends InstanceSet<O_TFRSet,O_TFR> implements O_TFRSet {

    // attributes
    @Override
    public void setObj_ID( UniqueId ref_Obj_ID ) throws XtumlException {
        for ( O_TFR o_tfr : this ) o_tfr.setObj_ID( ref_Obj_ID );
    }
    @Override
    public void setReturn_Dimensions( String m_Return_Dimensions ) throws XtumlException {
        for ( O_TFR o_tfr : this ) o_tfr.setReturn_Dimensions( m_Return_Dimensions );
    }
    @Override
    public void setAction_Semantics( String m_Action_Semantics ) throws XtumlException {
        for ( O_TFR o_tfr : this ) o_tfr.setAction_Semantics( m_Action_Semantics );
    }
    @Override
    public void setDescrip( String m_Descrip ) throws XtumlException {
        for ( O_TFR o_tfr : this ) o_tfr.setDescrip( m_Descrip );
    }
    @Override
    public void setName( String m_Name ) throws XtumlException {
        for ( O_TFR o_tfr : this ) o_tfr.setName( m_Name );
    }
    @Override
    public void setPrevious_Tfr_ID( UniqueId ref_Previous_Tfr_ID ) throws XtumlException {
        for ( O_TFR o_tfr : this ) o_tfr.setPrevious_Tfr_ID( ref_Previous_Tfr_ID );
    }
    @Override
    public void setInstance_Based( Scope m_Instance_Based ) throws XtumlException {
        for ( O_TFR o_tfr : this ) o_tfr.setInstance_Based( m_Instance_Based );
    }
    @Override
    public void setDT_ID( UniqueId ref_DT_ID ) throws XtumlException {
        for ( O_TFR o_tfr : this ) o_tfr.setDT_ID( ref_DT_ID );
    }
    @Override
    public void setTfr_ID( UniqueId m_Tfr_ID ) throws XtumlException {
        for ( O_TFR o_tfr : this ) o_tfr.setTfr_ID( m_Tfr_ID );
    }
    @Override
    public void setAction_Semantics_internal( String m_Action_Semantics_internal ) throws XtumlException {
        for ( O_TFR o_tfr : this ) o_tfr.setAction_Semantics_internal( m_Action_Semantics_internal );
    }
    @Override
    public void setSuc_Pars( ParseStatus m_Suc_Pars ) throws XtumlException {
        for ( O_TFR o_tfr : this ) o_tfr.setSuc_Pars( m_Suc_Pars );
    }
    @Override
    public void setDialect( ActionDialect m_Dialect ) throws XtumlException {
        for ( O_TFR o_tfr : this ) o_tfr.setDialect( m_Dialect );
    }


    // selections
    @Override
    public OperationMessageSet R1011_is_invoked_by_OperationMessage() throws XtumlException {
        OperationMessageSet operationmessageset = new OperationMessageSetImpl();
        for ( O_TFR o_tfr : this ) operationmessageset.addAll( o_tfr.R1011_is_invoked_by_OperationMessage() );
        return operationmessageset;
    }
    @Override
    public ModelClassSet R115_is_associated_with_ModelClass() throws XtumlException {
        ModelClassSet modelclassset = new ModelClassSetImpl();
        for ( O_TFR o_tfr : this ) modelclassset.add( o_tfr.R115_is_associated_with_ModelClass() );
        return modelclassset;
    }
    @Override
    public DataTypeSet R116_return_code_is_defined_by_DataType() throws XtumlException {
        DataTypeSet datatypeset = new DataTypeSetImpl();
        for ( O_TFR o_tfr : this ) datatypeset.add( o_tfr.R116_return_code_is_defined_by_DataType() );
        return datatypeset;
    }
    @Override
    public OperationParameterSet R117_contains_OperationParameter() throws XtumlException {
        OperationParameterSet operationparameterset = new OperationParameterSetImpl();
        for ( O_TFR o_tfr : this ) operationparameterset.addAll( o_tfr.R117_contains_OperationParameter() );
        return operationparameterset;
    }
    @Override
    public DimensionsSet R122_return_value_may_have_Dimensions() throws XtumlException {
        DimensionsSet dimensionsset = new DimensionsSetImpl();
        for ( O_TFR o_tfr : this ) dimensionsset.addAll( o_tfr.R122_return_value_may_have_Dimensions() );
        return dimensionsset;
    }
    @Override
    public O_TFRSet R125_precedes_O_TFR() throws XtumlException {
        O_TFRSet o_tfrset = new O_TFRSetImpl();
        for ( O_TFR o_tfr : this ) o_tfrset.add( o_tfr.R125_precedes_O_TFR() );
        return o_tfrset;
    }
    @Override
    public O_TFRSet R125_succeeds_O_TFR() throws XtumlException {
        O_TFRSet o_tfrset = new O_TFRSetImpl();
        for ( O_TFR o_tfr : this ) o_tfrset.add( o_tfr.R125_succeeds_O_TFR() );
        return o_tfrset;
    }
    @Override
    public DeferralSet R126_defers_execution_to_subtypes_across_Deferral() throws XtumlException {
        DeferralSet deferralset = new DeferralSetImpl();
        for ( O_TFR o_tfr : this ) deferralset.add( o_tfr.R126_defers_execution_to_subtypes_across_Deferral() );
        return deferralset;
    }
    @Override
    public OperationInvocationSet R673_OperationInvocation() throws XtumlException {
        OperationInvocationSet operationinvocationset = new OperationInvocationSetImpl();
        for ( O_TFR o_tfr : this ) operationinvocationset.addAll( o_tfr.R673_OperationInvocation() );
        return operationinvocationset;
    }
    @Override
    public OperationBodySet R696_OperationBody() throws XtumlException {
        OperationBodySet operationbodyset = new OperationBodySetImpl();
        for ( O_TFR o_tfr : this ) operationbodyset.add( o_tfr.R696_OperationBody() );
        return operationbodyset;
    }
    @Override
    public OperationValueSet R829_OperationValue() throws XtumlException {
        OperationValueSet operationvalueset = new OperationValueSetImpl();
        for ( O_TFR o_tfr : this ) operationvalueset.addAll( o_tfr.R829_OperationValue() );
        return operationvalueset;
    }


    @Override
    public O_TFR nullElement() {
        return O_TFRImpl.EMPTY_O_TFR;
    }

    @Override
    public O_TFRSet emptySet() {
      return new O_TFRSetImpl();
    }

    @Override
    public O_TFRSet value() {
        return this;
    }

    @Override
    public List<O_TFR> elements() {
        O_TFR[] elements = toArray(new O_TFR[0]);
        Arrays.sort(elements, (a, b) -> {
            try {
                return a.getName().compareTo(b.getName());
            } catch (XtumlException e) { return 0; }
        });
        return Arrays.asList(elements);
    }

}

==> tool-sql-1.1.11-sources.jar: io/ciera/tool/sql/ooaofooa/subsystem/impl/O_TFRSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.subsystem.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.body.OperationBodySet;
import io.ciera.tool.sql.ooaofooa.body.impl.OperationBodySetImpl;
import io.ciera.tool.sql.ooaofooa.domain.DataTypeSet;
import io.ciera.tool.sql.ooaofooa.domain.DimensionsSet;
import io.ciera.tool.sql.ooaofooa.domain.impl.DataTypeSetImpl;
import io.ciera.tool.sql.ooaofooa.domain.impl.DimensionsSetImpl;
import io.ciera.tool.sql.ooaofooa.invocation.OperationInvocationSet;
import io.ciera.tool.sql.ooaofooa.invocation.impl.OperationInvocationSetImpl;
import io.ciera.tool.sql.ooaofooa.message.OperationMessageSet;
import io.ciera.tool.sql.ooaofooa.message.impl.OperationMessageSetImpl;
import io.ciera.tool.sql.ooaofooa.subsystem.DeferralSet;
import io.ciera.tool.sql.ooaofooa.subsystem.ModelClassSet;
import io.ciera.tool.sql.ooaofooa.subsystem.O_TFR;
import io.ciera.tool.sql.ooaofooa.subsystem.O_TFRSet;
import io.ciera.tool.sql.ooaofooa.subsystem.OperationParameterSet;
import io.ciera.tool.sql.ooaofooa.subsystem.impl.DeferralSetImpl;
import io.ciera.tool.sql.ooaofooa.subsystem.impl.ModelClassSetImpl;
import io.ciera.tool.sql.ooaofooa.subsystem.impl.O_TFRSetImpl;
import io.ciera.tool.sql.ooaofooa.subsystem.impl.OperationParameterSetImpl;
import io.ciera.tool.sql.ooaofooa.value.OperationValueSet;
import io.ciera.tool.sql.ooaofooa.value.impl.OperationValueSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;

import ooaofooa.datatypes.ActionDialect;
import ooaofooa.datatypes.ParseStatus;
import ooaofooa.datatypes.Scope;


public class O_TFRSetImpl extends InstanceSet<O_TFRSet,O_TFR> implements O_TFRSet {

    public O_TFRSetImpl() {
    }

    public O_TFRSetImpl(Comparator<? super O_TFR> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setName( String m_Name ) throws XtumlException {
        for ( O_TFR o_tfr : this ) o_tfr.setName( m_Name );
    }
    @Override
    public void setAction_Semantics( String m_Action_Semantics ) throws XtumlException {
        for ( O_TFR o_tfr : this ) o_tfr.setAction_Semantics( m_Action_Semantics );
    }
    @Override
    public void setDT_ID( UniqueId ref_DT_ID ) throws XtumlException {
        for ( O_TFR o_tfr : this ) o_tfr.setDT_ID( ref_DT_ID );
    }
    @Override
    public void setObj_ID( UniqueId ref_Obj_ID ) throws XtumlException {
        for ( O_TFR o_tfr : this ) o_tfr.setObj_ID( ref_Obj_ID );
    }
    @Override
    public void setSuc_Pars( ParseStatus m_Suc_Pars ) throws XtumlException {
        for ( O_TFR o_tfr : this ) o_tfr.setSuc_Pars( m_Suc_Pars );
    }
    @Override
    public void setDialect( ActionDialect m_Dialect ) throws XtumlException {
        for ( O_TFR o_tfr : this ) o_tfr.setDialect( m_Dialect );
    }
    @Override
    public void setDescrip( String m_Descrip ) throws XtumlException {
        for ( O_TFR o_tfr : this ) o_tfr.setDescrip( m_Descrip );
    }
    @Override
    public void setInstance_Based( Scope m_Instance_Based ) throws XtumlException {
        for ( O_TFR o_tfr : this ) o_tfr.setInstance_Based( m_Instance_Based );
    }
    @Override
    public void setTfr_ID( UniqueId m_Tfr_ID ) throws XtumlException {
        for ( O_TFR o_tfr : this ) o_tfr.setTfr_ID( m_Tfr_ID );
    }
    @Override
    public void setReturn_Dimensions( String m_Return_Dimensions ) throws XtumlException {
        for ( O_TFR o_tfr : this ) o_tfr.setReturn_Dimensions( m_Return_Dimensions );
    }
    @Override
    public void setPrevious_Tfr_ID( UniqueId ref_Previous_Tfr_ID ) throws XtumlException {
        for ( O_TFR o_tfr : this ) o_tfr.setPrevious_Tfr_ID( ref_Previous_Tfr_ID );
    }
    @Override
    public void setAction_Semantics_internal( String m_Action_Semantics_internal ) throws XtumlException {
        for ( O_TFR o_tfr : this ) o_tfr.setAction_Semantics_internal( m_Action_Semantics_internal );
    }


    // selections
    @Override
    public OperationMessageSet R1011_is_invoked_by_OperationMessage() throws XtumlException {
        OperationMessageSet operationmessageset = new OperationMessageSetImpl();
        for ( O_TFR o_tfr : this ) operationmessageset.addAll( o_tfr.R1011_is_invoked_by_OperationMessage() );
        return operationmessageset;
    }
    @Override
    public ModelClassSet R115_is_associated_with_ModelClass() throws XtumlException {
        ModelClassSet modelclassset = new ModelClassSetImpl();
        for ( O_TFR o_tfr : this ) modelclassset.add( o_tfr.R115_is_associated_with_ModelClass() );
        return modelclassset;
    }
    @Override
    public DataTypeSet R116_return_code_is_defined_by_DataType() throws XtumlException {
        DataTypeSet datatypeset = new DataTypeSetImpl();
        for ( O_TFR o_tfr : this ) datatypeset.add( o_tfr.R116_return_code_is_defined_by_DataType() );
        return datatypeset;
    }
    @Override
    public OperationParameterSet R117_contains_OperationParameter() throws XtumlException {
        OperationParameterSet operationparameterset = new OperationParameterSetImpl();
        for ( O_TFR o_tfr : this ) operationparameterset.addAll( o_tfr.R117_contains_OperationParameter() );
        return operationparameterset;
    }
    @Override
    public DimensionsSet R122_return_value_may_have_Dimensions() throws XtumlException {
        DimensionsSet dimensionsset = new DimensionsSetImpl();
        for ( O_TFR o_tfr : this ) dimensionsset.addAll( o_tfr.R122_return_value_may_have_Dimensions() );
        return dimensionsset;
    }
    @Override
    public O_TFRSet R125_precedes_O_TFR() throws XtumlException {
        O_TFRSet o_tfrset = new O_TFRSetImpl();
        for ( O_TFR o_tfr : this ) o_tfrset.add( o_tfr.R125_precedes_O_TFR() );
        return o_tfrset;
    }
    @Override
    public O_TFRSet R125_succeeds_O_TFR() throws XtumlException {
        O_TFRSet o_tfrset = new O_TFRSetImpl();
        for ( O_TFR o_tfr : this ) o_tfrset.add( o_tfr.R125_succeeds_O_TFR() );
        return o_tfrset;
    }
    @Override
    public DeferralSet R126_defers_execution_to_subtypes_across_Deferral() throws XtumlException {
        DeferralSet deferralset = new DeferralSetImpl();
        for ( O_TFR o_tfr : this ) deferralset.add( o_tfr.R126_defers_execution_to_subtypes_across_Deferral() );
        return deferralset;
    }
    @Override
    public OperationInvocationSet R673_OperationInvocation() throws XtumlException {
        OperationInvocationSet operationinvocationset = new OperationInvocationSetImpl();
        for ( O_TFR o_tfr : this ) operationinvocationset.addAll( o_tfr.R673_OperationInvocation() );
        return operationinvocationset;
    }
    @Override
    public OperationBodySet R696_OperationBody() throws XtumlException {
        OperationBodySet operationbodyset = new OperationBodySetImpl();
        for ( O_TFR o_tfr : this ) operationbodyset.add( o_tfr.R696_OperationBody() );
        return operationbodyset;
    }
    @Override
    public OperationValueSet R829_OperationValue() throws XtumlException {
        OperationValueSet operationvalueset = new OperationValueSetImpl();
        for ( O_TFR o_tfr : this ) operationvalueset.addAll( o_tfr.R829_OperationValue() );
        return operationvalueset;
    }


    @Override
    public O_TFR nullElement() {
        return O_TFRImpl.EMPTY_O_TFR;
    }

    @Override
    public O_TFRSet emptySet() {
      return new O_TFRSetImpl();
    }

    @Override
    public O_TFRSet emptySet(Comparator<? super O_TFR> comp) {
      return new O_TFRSetImpl(comp);
    }

    @Override
    public O_TFRSet value() {
        return this;
    }

    @Override
    public List<O_TFR> elements() {
        O_TFR[] elements = toArray(new O_TFR[0]);
        Arrays.sort(elements, (a, b) -> {
            try {
                return a.getName().compareTo(b.getName());
            } catch (XtumlException e) { return 0; }
        });
        return Arrays.asList(elements);
    }

}
